yakumo.cinder.v2.volume

Package yakumo :: Package cinder :: Package v2 :: Module volume |
[hide private]
[frames] | no frames]

# Module volume

source code

Resource class and its manager for volumes on Block Storage V2 API

Classes | [hide private]
| Resource resource class for volumes on Block Storage V2 API
| Manager manager class for volumes on Block Storage V2 API

Variables | [hide private]
| ATTRIBUTE_MAPPING = ``[``(``'``name``'``,` `'``name``'``,` <yakumo.mapper.NoopClass`...``
| __package__ = ``'``yakumo.cinder.v2``'``

Variables Details | [hide private]

  ### ATTRIBUTE_MAPPING Value:
      [('name', 'name', mapper.Noop), ('description', 'description', mapper.
      Noop), ('volume_type', 'volume_type', mapper.Noop), ('size', 'size', m
      apper.Noop), ('availability_zone', 'availability_zone', mapper.Resourc
      e('availability_zone')), ('source_image', 'imageRef', mapper.Resource(
      'image')), ('source_volume', 'source_volid', mapper.Resource('cinder.v
      olume')), ('source_snapshot', 'snapshot_id', mapper.Resource('cinder.v
      olume_snapshot')), ('source_replica', 'source_replica', mapper.Noop),
      ('consistencygroup', 'consistencygroup_id', mapper.Resource('cinder.co
      ...